Rice area detection
===================

PyPI: https://pypi.org/project/dream_river/ 
##### Now!!! We are going to
improve the precision of detection. This is just Demo version. 
##Description This is a library that contain rice cultivated area
detection tools and other geospatial tools for jupyter environment on
https://sphere.gistda.or.th/ in part of Data Cube. Thus, you needs go to
sphere.gistda and register the account to access jupyter lab environment interactively from a browser.

How to setup
------------

open CMD or Terminal

.. code:: python

   pip install dream_river

How to use
----------

-  access jupyter lab environment from
   `sphere.gistda <https://datacube.gistda.or.th/hub/login?next=%2Fhub%2F>`__

Load Packages
~~~~~~~~~~~~~

.. code:: python

   import dream_river

Develop by : Pathakorn Usaha github: https://github.com/Pathakorn40
